﻿using System.Collections.Generic;

namespace Owl.Asf
{
	/// <summary>
	/// 定義済みのタグに関する情報を提供します。
	/// </summary>
	public static class AsfDefinedTags
	{
		/// <summary>
		/// 指定された名前を持つタグ情報を取得します。
		/// </summary>
		/// <param name="name">名前。</param>
		/// <returns>成功時はタグ情報。それ以外は null 参照。</returns>
		internal static AsfTagInfo GetInfo( string name )
		{
			AsfTagInfo info;
			return ( AsfDefinedTags.Infos.TryGetValue( name, out info ) ? info : null );
		}

		/// <summary>
		/// タグ情報のコレクションを取得します。
		/// </summary>
		/// <returns>タグ情報のコレクション。</returns>
		public static IEnumerable< AsfTagInfo > GetTags()
		{
			return AsfDefinedTags.Infos.Values;
		}

		/// <summary>
		/// 指定された名前を持つタグが定義されていることを調べます。
		/// </summary>
		/// <param name="name">名前。</param>
		/// <returns>定義されている場合は true。それ以外は false。</returns>
		internal static bool HasInfo( string name )
		{
			return AsfDefinedTags.Infos.ContainsKey( name );
		}

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo AsfLeakyBucketPairs = new AsfTagInfo( "ASFLeakyBucketPairs", AsfTagDataType.Binary );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo AspectRatioX = new AsfTagInfo( "AspectRatioX", AsfTagDataType.UInt32 );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo AspectRatioY = new AsfTagInfo( "AspectRatioY", AsfTagDataType.UInt32 );

		/// <summary>
		/// アーティストを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Author = new AsfTagInfo( "Author", AsfTagDataType.String, true );

		/// <summary>
		/// 音量の平均値を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo AverageLevel = new AsfTagInfo( "AverageLevel", AsfTagDataType.UInt32, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo BannerImageData = new AsfTagInfo( "BannerImageData", AsfTagDataType.Binary );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo BannerImageType = new AsfTagInfo( "BannerImageType", AsfTagDataType.UInt32 );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo BannerImageUrl = new AsfTagInfo( "BannerImageURL", AsfTagDataType.String );

		/// <summary>
		/// 平均ビットレートを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Bitrate = new AsfTagInfo( "Bitrate", AsfTagDataType.UInt32 );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo Broadcast = new AsfTagInfo( "Broadcast", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo BufferAverage = new AsfTagInfo( "BufferAverage", AsfTagDataType.UInt32 );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo CanSkipBackward = new AsfTagInfo( "Can_Skip_Backward", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo CanSkipForward = new AsfTagInfo( "Can_Skip_Forward", AsfTagDataType.Bool );

		/// <summary>
		/// 著作権情報を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Copyright = new AsfTagInfo( "Copyright", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo CopyrightUrl = new AsfTagInfo( "CopyrightURL", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo CurrentBitrate = new AsfTagInfo( "CurrentBitrate", AsfTagDataType.UInt32 );

		/// <summary>
		/// コメントを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Description = new AsfTagInfo( "Description", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmContentId = new AsfTagInfo( "DRM_ContentID", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmDrmHeaderContentDistributor = new AsfTagInfo( "DRM_DRMHeader_ContentDistributor", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmDrmHeaderContentId = new AsfTagInfo( "DRM_DRMHeader_ContentID", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmDrmHeaderIndividualizedVersion = new AsfTagInfo( "DRM_DRMHeader_IndividualizedVersion", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmDrmHeaderKeyId = new AsfTagInfo( "DRM_DRMHeader_KeyID", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmDrmHeaderLicenseAcqUrl = new AsfTagInfo( "DRM_DRMHeader_LicenseAcqURL", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmDrmHeaderSubscriptionContentId = new AsfTagInfo( "DRM_DRMHeader_SubscriptionContentID", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmDrmHeader = new AsfTagInfo( "DRM_DRMHeader", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmIndividualizedVersion = new AsfTagInfo( "DRM_IndividualizedVersion", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmKeyId = new AsfTagInfo( "DRM_KeyID", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmLaSignatureCert = new AsfTagInfo( "DRM_LASignatureCert", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmLaSignatureLicSrvCert = new AsfTagInfo( "DRM_LASignatureLicSrvCert", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmLaSignaturePrivKey = new AsfTagInfo( "DRM_LASignaturePrivKey", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmLaSignatureRootCert = new AsfTagInfo( "DRM_LASignatureRootCert", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmLicenseAcqUrl = new AsfTagInfo( "DRM_LicenseAcqURL", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmLicenseId = new AsfTagInfo( "DRM_LicenseID", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmSourceId = new AsfTagInfo( "DRM_SourceID", AsfTagDataType.UInt32 );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo DrmV1LicenseAcqUrl = new AsfTagInfo( "DRM_V1LicenseAcqURL", AsfTagDataType.String );

		/// <summary>
		/// 演奏時間を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Duration = new AsfTagInfo( "Duration", AsfTagDataType.UInt64 );

		/// <summary>
		/// ファイルサイズを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo FileSize = new AsfTagInfo( "FileSize", AsfTagDataType.UInt64 );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo HasArbitraryDataStream = new AsfTagInfo( "HasArbitraryDataStream", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo HasAttachedImages = new AsfTagInfo( "HasAttachedImages", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo HasAudio = new AsfTagInfo( "HasAudio", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo HasFileTransferStream = new AsfTagInfo( "HasFileTransferStream", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo HasImage = new AsfTagInfo( "HasImage", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo HasScript = new AsfTagInfo( "HasScript", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo HasVideo = new AsfTagInfo( "HasVideo", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo IsProtected = new AsfTagInfo( "Is_Protected", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo IsTrusted = new AsfTagInfo( "Is_Trusted", AsfTagDataType.Bool );

		/// <summary>
		/// 国際標準視聴覚番号 ( International Standard Audiovisual Number ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Isan = new AsfTagInfo( "WM/ISAN", AsfTagDataType.String, true );

		/// <summary>
		/// 可変ビットレートでエンコードされたことを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo IsVBR = new AsfTagInfo( "IsVBR", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo NscAddress = new AsfTagInfo( "NSC_Address", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo NscDescription = new AsfTagInfo( "NSC_Description", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo NscEmail = new AsfTagInfo( "NSC_Email", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo NscName = new AsfTagInfo( "NSC_Name", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo NscPhone = new AsfTagInfo( "NSC_Phone", AsfTagDataType.String );

		/// <summary>
		/// ビデオストリームのフレーム数を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo NumberOfFrames = new AsfTagInfo( "NumberOfFrames", AsfTagDataType.UInt64, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo OptimalBitrate = new AsfTagInfo( "OptimalBitrate", AsfTagDataType.UInt32 );

		/// <summary>
		/// 音量の最大値を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo PeakValue = new AsfTagInfo( "PeakValue", AsfTagDataType.UInt32, true );

		/// <summary>
		/// 保護者による制限を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Rating = new AsfTagInfo( "Rating", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo Seekable = new AsfTagInfo( "Seekable", AsfTagDataType.Bool );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo Signature_Name = new AsfTagInfo( "Signature_Name", AsfTagDataType.String );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo Stridable = new AsfTagInfo( "Stridable", AsfTagDataType.Bool );

		/// <summary>
		/// タイトルを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo Title = new AsfTagInfo( "Title", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo VbrPeak = new AsfTagInfo( "VBRPeak", AsfTagDataType.UInt32 );

		/// <summary>
		/// アルバムのアーティスト名を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmAlbumArtist = new AsfTagInfo( "WM/AlbumArtist", AsfTagDataType.String, true );

		/// <summary>
		/// アルバムのジャケット画像に関する情報サイトの URL を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmAlbumCoverUrl = new AsfTagInfo( "WM/AlbumCoverURL", AsfTagDataType.String, true );

		/// <summary>
		/// アルバム名を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmAlbumTitle = new AsfTagInfo( "WM/AlbumTitle", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmAsfPacketCount = new AsfTagInfo( "WM/ASFPacketCount", AsfTagDataType.UInt64 );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmAsfSecurityObjectsSize = new AsfTagInfo( "WM/ASFSecurityObjectsSize", AsfTagDataType.UInt64 );

		/// <summary>
		/// 音楽ファイルのサイト ( アルバムやアーティスト情報 ) URL を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmAudioFileUrl = new AsfTagInfo( "WM/AudioFileURL", AsfTagDataType.String, true );

		/// <summary>
		/// 音楽の使用された作品 ( 映画や TV など ) のサイトへの URL を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmAudioSourceUrl = new AsfTagInfo( "WM/AudioSourceURL", AsfTagDataType.String, true );

		/// <summary>
		/// アーティストの URL を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmAuthorUrl = new AsfTagInfo( "WM/AuthorURL", AsfTagDataType.String, true );

		/// <summary>
		/// テンポ ( 1 分間の拍数 ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmBeatsPerMinute = new AsfTagInfo( "WM/BeatsPerMinute", AsfTagDataType.String, true );

		/// <summary>
		/// カテゴリを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmCategory = new AsfTagInfo( "WM/Category", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmCodec = new AsfTagInfo( "WM/Codec", AsfTagDataType.String );

		/// <summary>
		/// 作曲者を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmComposer = new AsfTagInfo( "WM/Composer", AsfTagDataType.String, true );

		/// <summary>
		/// 指揮者を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmConductor = new AsfTagInfo( "WM/Conductor", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmContainerFormat = new AsfTagInfo( "WM/ContainerFormat", AsfTagDataType.Binary );

		/// <summary>
		/// ファイルの提供者を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmContentDistributor = new AsfTagInfo( "WM/ContentDistributor", AsfTagDataType.String, true );

		/// <summary>
		/// 所属するグループの情報 ( 音楽ならば CD、ビデオならばシリーズの情報など ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmContentGroupDescription = new AsfTagInfo( "WM/ContentGroupDescription", AsfTagDataType.String, true );

		/// <summary>
		/// ディレクターを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmDirector = new AsfTagInfo( "WM/Director", AsfTagDataType.String, true );

		/// <summary>
		/// DRM で保護されていることを示す情報を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmDrm = new AsfTagInfo( "WM/DRM", AsfTagDataType.String, true );

		/// <summary>
		/// DVD の識別子を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmDvdId = new AsfTagInfo( "WM/DVDID", AsfTagDataType.String, true );

		/// <summary>
		/// エンコードをおこなった人を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmEncodedBy = new AsfTagInfo( "WM/EncodedBy", AsfTagDataType.String, true );

		/// <summary>
		/// エンコード設定を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmEncodingSettings = new AsfTagInfo( "WM/EncodingSettings", AsfTagDataType.String, true );

		/// <summary>
		/// エンコードをおこなった時間を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmEncodingTime = new AsfTagInfo( "WM/EncodingTime", AsfTagDataType.UInt64, true );

		/// <summary>
		/// ジャンルを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmGenre = new AsfTagInfo( "WM/Genre", AsfTagDataType.String, true );

		/// <summary>
		/// ジャンル ID を示すタグ定義を取得します。
		/// この情報は ID3v2 の TCON タグに準拠しています。
		/// 通常、"(17) Rock" のように、括弧にジャンルを表す数値を入れ、後続の文字列にジャンル名を格納します。
		/// 詳細は ID3v2 の仕様を参照してください。
		/// </summary>
		public static readonly AsfTagInfo WmGenreId = new AsfTagInfo( "WM/GenreID", AsfTagDataType.String, true );

		/// <summary>
		/// 曲頭のキー ( C、Am、F♯ といった調の文字列 ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmInitialKey = new AsfTagInfo( "WM/InitialKey", AsfTagDataType.String, true );

		/// <summary>
		/// 国際標準レコーディングコード（ International Standard Recording Code ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmIsrc = new AsfTagInfo( "WM/ISRC", AsfTagDataType.String, true );

		/// <summary>
		/// 言語を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmLanguage = new AsfTagInfo( "WM/Language", AsfTagDataType.String, true );

		/// <summary>
		/// 歌詞を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmLyrics = new AsfTagInfo( "WM/Lyrics", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmLyricsSynchronised = new AsfTagInfo( "WM/Lyrics_Synchronised", AsfTagDataType.Binary );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmMCDI = new AsfTagInfo( "WM/MCDI", AsfTagDataType.Binary );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmMediaClassPrimaryId = new AsfTagInfo( "WM/MediaClassPrimaryID", AsfTagDataType.Guid );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmMediaClassSecondaryId = new AsfTagInfo( "WM/MediaClassSecondaryID", AsfTagDataType.Guid );

		/// <summary>
		/// 放送をおこなったメディア名を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaCredits = new AsfTagInfo( "WM/MediaCredits", AsfTagDataType.String, true );

		/// <summary>
		/// 放送時におけるテープ遅延の有無を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsDelay = new AsfTagInfo( "WM/MediaIsDelay", AsfTagDataType.Bool, true );

		/// <summary>
		/// シリーズの最終回であることを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsFinale = new AsfTagInfo( "WM/MediaIsFinale", AsfTagDataType.Bool, true );

		/// <summary>
		/// 生放送であることを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsLive = new AsfTagInfo( "WM/MediaIsLive", AsfTagDataType.Bool, true );

		/// <summary>
		/// シリーズの初回であることを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsPremiere = new AsfTagInfo( "WM/MediaIsPremiere", AsfTagDataType.Bool, true );

		/// <summary>
		/// 再放送であることを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsRepeat = new AsfTagInfo( "WM/MediaIsRepeat", AsfTagDataType.Bool, true );

		/// <summary>
		/// 音声多重放送 ( Second Audio Program ) であることを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsSap = new AsfTagInfo( "WM/MediaIsSAP", AsfTagDataType.Bool, true );

		/// <summary>
		/// ステレオ放送であることを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsStereo = new AsfTagInfo( "WM/MediaIsStereo", AsfTagDataType.Bool, true );

		/// <summary>
		/// 字幕を持つことを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsSubtitled = new AsfTagInfo( "WM/MediaIsSubtitled", AsfTagDataType.Bool, true );

		/// <summary>
		/// 収録放送されたことを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaIsTape = new AsfTagInfo( "WM/MediaIsTape", AsfTagDataType.Bool, true );

		/// <summary>
		/// コンテンツ配信をおこなうネットワーク情報を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaNetworkAffiliation = new AsfTagInfo( "WM/MediaNetworkAffiliation", AsfTagDataType.String, true );

		/// <summary>
		/// 放送日時を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaOriginalBroadcastDateTime = new AsfTagInfo( "WM/MediaOriginalBroadcastDateTime", AsfTagDataType.String, true );

		/// <summary>
		/// 放送したチャンネルを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaOriginalChannel = new AsfTagInfo( "WM/MediaOriginalChannel", AsfTagDataType.String, true );

		/// <summary>
		/// 放送局の識別信号を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaStationCallSign = new AsfTagInfo( "WM/MediaStationCallSign", AsfTagDataType.String, true );

		/// <summary>
		/// 放送局の名前を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMediaStationName = new AsfTagInfo( "WM/MediaStationName", AsfTagDataType.String, true );

		/// <summary>
		/// ファイルを更新したグループ、または個人名を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmModifiedBy = new AsfTagInfo( "WM/ModifiedBy", AsfTagDataType.String, true );

		/// <summary>
		/// 曲の雰囲気を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmMood = new AsfTagInfo( "WM/Mood", AsfTagDataType.String, true );

		/// <summary>
		/// 曲の初出となるアルバムを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmOriginalAlbumTitle = new AsfTagInfo( "WM/OriginalAlbumTitle", AsfTagDataType.String, true );

		/// <summary>
		/// 原曲のアーティストを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmOriginalArtist = new AsfTagInfo( "WM/OriginalArtist", AsfTagDataType.String, true );

		/// <summary>
		/// 元のファイル名を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmOriginalFilename = new AsfTagInfo( "WM/OriginalFilename", AsfTagDataType.String, true );

		/// <summary>
		/// 原曲の作詞者を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmOriginalLyricist = new AsfTagInfo( "WM/OriginalLyricist", AsfTagDataType.String, true );

		/// <summary>
		/// 原曲がリリースされた時間を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmOriginalReleaseTime = new AsfTagInfo( "WM/OriginalReleaseTime", AsfTagDataType.String, true );

		/// <summary>
		/// 原曲がリリースされた年を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmOriginalReleaseYear = new AsfTagInfo( "WM/OriginalReleaseYear", AsfTagDataType.String, true );

		/// <summary>
		/// 保護者による制限を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmParentalRating = new AsfTagInfo( "WM/ParentalRating", AsfTagDataType.String, true );

		/// <summary>
		/// 保護者による制限の理由を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmParentalRatingReason = new AsfTagInfo( "WM/ParentalRatingReason", AsfTagDataType.String, true );

		/// <summary>
		/// 曲の属するグループ内の番号 ( スラッシュ区切りの文字列 ) を示すタグ定義を取得します。
		/// 複数枚や複数の組曲で構成されるアルバムの場合、それらの総数と何番目に位置するかを表します。
		/// 例えば 3 枚組のアルバムにおいて、2 枚目に属する曲ならば "2/3" となります。
		/// </summary>
		public static readonly AsfTagInfo WmPartOfSet = new AsfTagInfo( "WM/PartOfSet", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmPeakBitrate = new AsfTagInfo( "WM/PeakBitrate", AsfTagDataType.UInt32 );

		/// <summary>
		/// 音楽の年代を示すタグ定義を取得します。
		/// 例えばバロックやルネッサンスなど、ある時代を指すために使用します。
		/// </summary>
		public static readonly AsfTagInfo WmPeriod = new AsfTagInfo( "WM/Period", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmPicture = new AsfTagInfo( "WM/Picture", AsfTagDataType.Binary );

		/// <summary>
		/// プレイリスト内の曲を再生する前に必要な遅延時間 ( ミリ秒単位 ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmPlaylistDelay = new AsfTagInfo( "WM/PlaylistDelay", AsfTagDataType.String, true );

		/// <summary>
		/// プロデューサーを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmProducer = new AsfTagInfo( "WM/Producer", AsfTagDataType.String, true );

		/// <summary>
		/// プロモーション用の URL を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmPromotionUrl = new AsfTagInfo( "WM/PromotionURL", AsfTagDataType.String, true );

		/// <summary>
		/// コンテンツを保護する方法の種別を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmProtectionType = new AsfTagInfo( "WM/ProtectionType", AsfTagDataType.String, true );

		/// <summary>
		/// メタデータ提供サービス ( CDDB や AMG など ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmProvider = new AsfTagInfo( "WM/Provider", AsfTagDataType.String, true );

		/// <summary>
		/// コンテンツを配信するプロパイダの著作権情報を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmProviderCopyright = new AsfTagInfo( "WM/ProviderCopyright", AsfTagDataType.String, true );

		/// <summary>
		/// メタデータ提供サービスによる評価を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmProviderRating = new AsfTagInfo( "WM/ProviderRating", AsfTagDataType.String, true );

		/// <summary>
		/// メタデータ提供サービスによるスタイル ( 副次的なジャンル ) 指定を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmProviderStyle = new AsfTagInfo( "WM/ProviderStyle", AsfTagDataType.String, true );

		/// <summary>
		/// 曲の発行元 ( レーベル ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmPublisher = new AsfTagInfo( "WM/Publisher", AsfTagDataType.String, true );

		/// <summary>
		/// ラジオ局の名前を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmRadioStationName = new AsfTagInfo( "WM/RadioStationName", AsfTagDataType.String, true );

		/// <summary>
		/// ラジオ局の所有者を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmRadioStationOwner = new AsfTagInfo( "WM/RadioStationOwner", AsfTagDataType.String, true );

		/// <summary>
		/// 複数のユーザーによる評価を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmSharedUserRating = new AsfTagInfo( "WM/SharedUserRating", AsfTagDataType.UInt32, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmStreamTypeInfo = new AsfTagInfo( "WM/StreamTypeInfo", AsfTagDataType.Binary );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmSubscriptionContentId = new AsfTagInfo( "WM/SubscriptionContentID", AsfTagDataType.String, true );

		/// <summary>
		/// 副題を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmSubTitle = new AsfTagInfo( "WM/SubTitle", AsfTagDataType.String, true );

		/// <summary>
		/// 副題の補足情報を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmSubTitleDescription = new AsfTagInfo( "WM/SubTitleDescription", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmText = new AsfTagInfo( "WM/Text", AsfTagDataType.Binary );

		/// <summary>
		/// ファイル作成に使用したツールを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmToolName = new AsfTagInfo( "WM/ToolName", AsfTagDataType.String, true );

		/// <summary>
		/// ファイル作成に使用したツールのバージョン情報を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmToolVersion = new AsfTagInfo( "WM/ToolVersion", AsfTagDataType.String, true );

		/// <summary>
		/// トラック番号 ( 0 から開始 ) を示すタグ定義を取得します。
		/// このデータは下位互換のために残されており、現在は WmTrackNumber を代りに使用します。
		/// </summary>
		public static readonly AsfTagInfo WmTrack = new AsfTagInfo( "WM/Track", AsfTagDataType.String, true );

		/// <summary>
		/// トラック番号 ( 1 から開始 ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmTrackNumber = new AsfTagInfo( "WM/TrackNumber", AsfTagDataType.String, true );

		/// <summary>
		/// ファイルの識別子 ( セミコロンで区切られた任意の値 ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmUniqueFileIdentifier = new AsfTagInfo( "WM/UniqueFileIdentifier", AsfTagDataType.String, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmUserWebUrl = new AsfTagInfo( "WM/UserWebURL", AsfTagDataType.Binary );

		/// <summary>
		/// クローズドキャプションを含むことを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmVideoClosedCaptioning = new AsfTagInfo( "WM/VideoClosedCaptioning", AsfTagDataType.Bool, true );

		/// <summary>
		/// ビデオのフレームレート
		/// </summary>
		public static readonly AsfTagInfo WmVideoFrameRate = new AsfTagInfo( "WM/VideoFrameRate", AsfTagDataType.UInt32, true );

		/// <summary>
		/// ビデオの高さ ( ピクセル単位 ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmVideoHeight = new AsfTagInfo( "WM/VideoHeight", AsfTagDataType.UInt32, true );

		/// <summary>
		/// ビデオの幅 ( ピクセル単位 ) を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmVideoWidth = new AsfTagInfo( "WM/VideoWidth", AsfTagDataType.UInt32, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmWmaDRCAverageReference = new AsfTagInfo( "WM/WMADRCAverageReference", AsfTagDataType.UInt32 );

		/// <summary>
		/// 平均音量レベルを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmWmaDRCAverageTarget = new AsfTagInfo( "WM/WMADRCAverageTarget", AsfTagDataType.UInt32, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmWmaDRCPeakReference = new AsfTagInfo( "WM/WMADRCPeakReference", AsfTagDataType.UInt32 );

		/// <summary>
		/// 最大音量レベルを示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmWmaDRCPeakTarget = new AsfTagInfo( "WM/WMADRCPeakTarget", AsfTagDataType.UInt32, true );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmWmCollectionGroupId = new AsfTagInfo( "WM/WMCollectionGroupID", AsfTagDataType.Guid );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmWmCollectionId = new AsfTagInfo( "WM/WMCollectionID", AsfTagDataType.Guid );

		/// <summary>
		/// 
		/// </summary>
		public static readonly AsfTagInfo WmWmContentId = new AsfTagInfo( "WM/WMContentID", AsfTagDataType.Guid );

		/// <summary>
		/// 元ファイルの著作権保護方法を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmWmShadowFileSourceDrmType = new AsfTagInfo( "WM/WMShadowFileSourceDRMType", AsfTagDataType.String, true );

		/// <summary>
		/// 元ファイルの種別を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmWmShadowFileSourceFileType = new AsfTagInfo( "WM/WMShadowFileSourceFileType", AsfTagDataType.String, true );

		/// <summary>
		/// 作詞者を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmWriter = new AsfTagInfo( "WM/Writer", AsfTagDataType.String, true );

		/// <summary>
		/// リリースされた年を示すタグ定義を取得します。
		/// </summary>
		public static readonly AsfTagInfo WmYear = new AsfTagInfo( "WM/Year", AsfTagDataType.String, true );

		/// <summary>
		/// タグ名をキーとするタグ情報のディクショナリ。
		/// </summary>
		private static readonly Dictionary< string, AsfTagInfo > Infos = new Dictionary< string, AsfTagInfo >()
		{
			{ AsfDefinedTags.AsfLeakyBucketPairs.Name,               AsfDefinedTags.AsfLeakyBucketPairs               },
			{ AsfDefinedTags.AspectRatioX.Name,                      AsfDefinedTags.AspectRatioX                      },
			{ AsfDefinedTags.AspectRatioY.Name,                      AsfDefinedTags.AspectRatioY                      },
			{ AsfDefinedTags.Author.Name,                            AsfDefinedTags.Author                            },
			{ AsfDefinedTags.AverageLevel.Name,                      AsfDefinedTags.AverageLevel                      },
			{ AsfDefinedTags.BannerImageData.Name,                   AsfDefinedTags.BannerImageData                   },
			{ AsfDefinedTags.BannerImageType.Name,                   AsfDefinedTags.BannerImageType                   },
			{ AsfDefinedTags.BannerImageUrl.Name,                    AsfDefinedTags.BannerImageUrl                    },
			{ AsfDefinedTags.Bitrate.Name,                           AsfDefinedTags.Bitrate                           },
			{ AsfDefinedTags.Broadcast.Name,                         AsfDefinedTags.Broadcast                         },
			{ AsfDefinedTags.BufferAverage.Name,                     AsfDefinedTags.BufferAverage                     },
			{ AsfDefinedTags.CanSkipBackward.Name,                   AsfDefinedTags.CanSkipBackward                   },
			{ AsfDefinedTags.CanSkipForward.Name,                    AsfDefinedTags.CanSkipForward                    },
			{ AsfDefinedTags.Copyright.Name,                         AsfDefinedTags.Copyright                         },
			{ AsfDefinedTags.CopyrightUrl.Name,                      AsfDefinedTags.CopyrightUrl                      },
			{ AsfDefinedTags.CurrentBitrate.Name,                    AsfDefinedTags.CurrentBitrate                    },
			{ AsfDefinedTags.Description.Name,                       AsfDefinedTags.Description                       },
			{ AsfDefinedTags.DrmContentId.Name,                      AsfDefinedTags.DrmContentId                      },
			{ AsfDefinedTags.DrmDrmHeaderContentDistributor.Name,    AsfDefinedTags.DrmDrmHeaderContentDistributor    },
			{ AsfDefinedTags.DrmDrmHeaderContentId.Name,             AsfDefinedTags.DrmDrmHeaderContentId             },
			{ AsfDefinedTags.DrmDrmHeaderIndividualizedVersion.Name, AsfDefinedTags.DrmDrmHeaderIndividualizedVersion },
			{ AsfDefinedTags.DrmDrmHeaderKeyId.Name,                 AsfDefinedTags.DrmDrmHeaderKeyId                 },
			{ AsfDefinedTags.DrmDrmHeaderLicenseAcqUrl.Name,         AsfDefinedTags.DrmDrmHeaderLicenseAcqUrl         },
			{ AsfDefinedTags.DrmDrmHeaderSubscriptionContentId.Name, AsfDefinedTags.DrmDrmHeaderSubscriptionContentId },
			{ AsfDefinedTags.DrmDrmHeader.Name,                      AsfDefinedTags.DrmDrmHeader                      },
			{ AsfDefinedTags.DrmIndividualizedVersion.Name,          AsfDefinedTags.DrmIndividualizedVersion          },
			{ AsfDefinedTags.DrmKeyId.Name,                          AsfDefinedTags.DrmKeyId                          },
			{ AsfDefinedTags.DrmLaSignatureCert.Name,                AsfDefinedTags.DrmLaSignatureCert                },
			{ AsfDefinedTags.DrmLaSignatureLicSrvCert.Name,          AsfDefinedTags.DrmLaSignatureLicSrvCert          },
			{ AsfDefinedTags.DrmLaSignaturePrivKey.Name,             AsfDefinedTags.DrmLaSignaturePrivKey             },
			{ AsfDefinedTags.DrmLaSignatureRootCert.Name,            AsfDefinedTags.DrmLaSignatureRootCert            },
			{ AsfDefinedTags.DrmLicenseAcqUrl.Name,                  AsfDefinedTags.DrmLicenseAcqUrl                  },
			{ AsfDefinedTags.DrmLicenseId.Name,                      AsfDefinedTags.DrmLicenseId                      },
			{ AsfDefinedTags.DrmSourceId.Name,                       AsfDefinedTags.DrmSourceId                       },
			{ AsfDefinedTags.DrmV1LicenseAcqUrl.Name,                AsfDefinedTags.DrmV1LicenseAcqUrl                },
			{ AsfDefinedTags.Duration.Name,                          AsfDefinedTags.Duration                          },
			{ AsfDefinedTags.FileSize.Name,                          AsfDefinedTags.FileSize                          },
			{ AsfDefinedTags.HasArbitraryDataStream.Name,            AsfDefinedTags.HasArbitraryDataStream            },
			{ AsfDefinedTags.HasAttachedImages.Name,                 AsfDefinedTags.HasAttachedImages                 },
			{ AsfDefinedTags.HasAudio.Name,                          AsfDefinedTags.HasAudio                          },
			{ AsfDefinedTags.HasFileTransferStream.Name,             AsfDefinedTags.HasFileTransferStream             },
			{ AsfDefinedTags.HasImage.Name,                          AsfDefinedTags.HasImage                          },
			{ AsfDefinedTags.HasScript.Name,                         AsfDefinedTags.HasScript                         },
			{ AsfDefinedTags.HasVideo.Name,                          AsfDefinedTags.HasVideo                          },
			{ AsfDefinedTags.IsProtected.Name,                       AsfDefinedTags.IsProtected                       },
			{ AsfDefinedTags.IsTrusted.Name,                         AsfDefinedTags.IsTrusted                         },
			{ AsfDefinedTags.Isan.Name,                              AsfDefinedTags.Isan                              },
			{ AsfDefinedTags.IsVBR.Name,                             AsfDefinedTags.IsVBR                             },
			{ AsfDefinedTags.NscAddress.Name,                        AsfDefinedTags.NscAddress                        },
			{ AsfDefinedTags.NscDescription.Name,                    AsfDefinedTags.NscDescription                    },
			{ AsfDefinedTags.NscEmail.Name,                          AsfDefinedTags.NscEmail                          },
			{ AsfDefinedTags.NscName.Name,                           AsfDefinedTags.NscName                           },
			{ AsfDefinedTags.NscPhone.Name,                          AsfDefinedTags.NscPhone                          },
			{ AsfDefinedTags.NumberOfFrames.Name,                    AsfDefinedTags.NumberOfFrames                    },
			{ AsfDefinedTags.OptimalBitrate.Name,                    AsfDefinedTags.OptimalBitrate                    },
			{ AsfDefinedTags.PeakValue.Name,                         AsfDefinedTags.PeakValue                         },
			{ AsfDefinedTags.Rating.Name,                            AsfDefinedTags.Rating                            },
			{ AsfDefinedTags.Seekable.Name,                          AsfDefinedTags.Seekable                          },
			{ AsfDefinedTags.Signature_Name.Name,                    AsfDefinedTags.Signature_Name                    },
			{ AsfDefinedTags.Stridable.Name,                         AsfDefinedTags.Stridable                         },
			{ AsfDefinedTags.Title.Name,                             AsfDefinedTags.Title                             },
			{ AsfDefinedTags.VbrPeak.Name,                           AsfDefinedTags.VbrPeak                           },
			{ AsfDefinedTags.WmAlbumArtist.Name,                     AsfDefinedTags.WmAlbumArtist                     },
			{ AsfDefinedTags.WmAlbumCoverUrl.Name,                   AsfDefinedTags.WmAlbumCoverUrl                   },
			{ AsfDefinedTags.WmAlbumTitle.Name,                      AsfDefinedTags.WmAlbumTitle                      },
			{ AsfDefinedTags.WmAsfPacketCount.Name,                  AsfDefinedTags.WmAsfPacketCount                  },
			{ AsfDefinedTags.WmAsfSecurityObjectsSize.Name,          AsfDefinedTags.WmAsfSecurityObjectsSize          },
			{ AsfDefinedTags.WmAudioFileUrl.Name,                    AsfDefinedTags.WmAudioFileUrl                    },
			{ AsfDefinedTags.WmAudioSourceUrl.Name,                  AsfDefinedTags.WmAudioSourceUrl                  },
			{ AsfDefinedTags.WmAuthorUrl.Name,                       AsfDefinedTags.WmAuthorUrl                       },
			{ AsfDefinedTags.WmBeatsPerMinute.Name,                  AsfDefinedTags.WmBeatsPerMinute                  },
			{ AsfDefinedTags.WmCategory.Name,                        AsfDefinedTags.WmCategory                        },
			{ AsfDefinedTags.WmCodec.Name,                           AsfDefinedTags.WmCodec                           },
			{ AsfDefinedTags.WmComposer.Name,                        AsfDefinedTags.WmComposer                        },
			{ AsfDefinedTags.WmConductor.Name,                       AsfDefinedTags.WmConductor                       },
			{ AsfDefinedTags.WmContainerFormat.Name,                 AsfDefinedTags.WmContainerFormat                 },
			{ AsfDefinedTags.WmContentDistributor.Name,              AsfDefinedTags.WmContentDistributor              },
			{ AsfDefinedTags.WmContentGroupDescription.Name,         AsfDefinedTags.WmContentGroupDescription         },
			{ AsfDefinedTags.WmDirector.Name,                        AsfDefinedTags.WmDirector                        },
			{ AsfDefinedTags.WmDrm.Name,                             AsfDefinedTags.WmDrm                             },
			{ AsfDefinedTags.WmDvdId.Name,                           AsfDefinedTags.WmDvdId                           },
			{ AsfDefinedTags.WmEncodedBy.Name,                       AsfDefinedTags.WmEncodedBy                       },
			{ AsfDefinedTags.WmEncodingSettings.Name,                AsfDefinedTags.WmEncodingSettings                },
			{ AsfDefinedTags.WmEncodingTime.Name,                    AsfDefinedTags.WmEncodingTime                    },
			{ AsfDefinedTags.WmGenre.Name,                           AsfDefinedTags.WmGenre                           },
			{ AsfDefinedTags.WmGenreId.Name,                         AsfDefinedTags.WmGenreId                         },
			{ AsfDefinedTags.WmInitialKey.Name,                      AsfDefinedTags.WmInitialKey                      },
			{ AsfDefinedTags.WmIsrc.Name,                            AsfDefinedTags.WmIsrc                            },
			{ AsfDefinedTags.WmLanguage.Name,                        AsfDefinedTags.WmLanguage                        },
			{ AsfDefinedTags.WmLyrics.Name,                          AsfDefinedTags.WmLyrics                          },
			{ AsfDefinedTags.WmLyricsSynchronised.Name,              AsfDefinedTags.WmLyricsSynchronised              },
			{ AsfDefinedTags.WmMCDI.Name,                            AsfDefinedTags.WmMCDI                            },
			{ AsfDefinedTags.WmMediaClassPrimaryId.Name,             AsfDefinedTags.WmMediaClassPrimaryId             },
			{ AsfDefinedTags.WmMediaClassSecondaryId.Name,           AsfDefinedTags.WmMediaClassSecondaryId           },
			{ AsfDefinedTags.WmMediaCredits.Name,                    AsfDefinedTags.WmMediaCredits                    },
			{ AsfDefinedTags.WmMediaIsDelay.Name,                    AsfDefinedTags.WmMediaIsDelay                    },
			{ AsfDefinedTags.WmMediaIsFinale.Name,                   AsfDefinedTags.WmMediaIsFinale                   },
			{ AsfDefinedTags.WmMediaIsLive.Name,                     AsfDefinedTags.WmMediaIsLive                     },
			{ AsfDefinedTags.WmMediaIsPremiere.Name,                 AsfDefinedTags.WmMediaIsPremiere                 },
			{ AsfDefinedTags.WmMediaIsRepeat.Name,                   AsfDefinedTags.WmMediaIsRepeat                   },
			{ AsfDefinedTags.WmMediaIsSap.Name,                      AsfDefinedTags.WmMediaIsSap                      },
			{ AsfDefinedTags.WmMediaIsStereo.Name,                   AsfDefinedTags.WmMediaIsStereo                   },
			{ AsfDefinedTags.WmMediaIsSubtitled.Name,                AsfDefinedTags.WmMediaIsSubtitled                },
			{ AsfDefinedTags.WmMediaIsTape.Name,                     AsfDefinedTags.WmMediaIsTape                     },
			{ AsfDefinedTags.WmMediaNetworkAffiliation.Name,         AsfDefinedTags.WmMediaNetworkAffiliation         },
			{ AsfDefinedTags.WmMediaOriginalBroadcastDateTime.Name,  AsfDefinedTags.WmMediaOriginalBroadcastDateTime  },
			{ AsfDefinedTags.WmMediaOriginalChannel.Name,            AsfDefinedTags.WmMediaOriginalChannel            },
			{ AsfDefinedTags.WmMediaStationCallSign.Name,            AsfDefinedTags.WmMediaStationCallSign            },
			{ AsfDefinedTags.WmMediaStationName.Name,                AsfDefinedTags.WmMediaStationName                },
			{ AsfDefinedTags.WmModifiedBy.Name,                      AsfDefinedTags.WmModifiedBy                      },
			{ AsfDefinedTags.WmMood.Name,                            AsfDefinedTags.WmMood                            },
			{ AsfDefinedTags.WmOriginalAlbumTitle.Name,              AsfDefinedTags.WmOriginalAlbumTitle              },
			{ AsfDefinedTags.WmOriginalArtist.Name,                  AsfDefinedTags.WmOriginalArtist                  },
			{ AsfDefinedTags.WmOriginalFilename.Name,                AsfDefinedTags.WmOriginalFilename                },
			{ AsfDefinedTags.WmOriginalLyricist.Name,                AsfDefinedTags.WmOriginalLyricist                },
			{ AsfDefinedTags.WmOriginalReleaseTime.Name,             AsfDefinedTags.WmOriginalReleaseTime             },
			{ AsfDefinedTags.WmOriginalReleaseYear.Name,             AsfDefinedTags.WmOriginalReleaseYear             },
			{ AsfDefinedTags.WmParentalRating.Name,                  AsfDefinedTags.WmParentalRating                  },
			{ AsfDefinedTags.WmParentalRatingReason.Name,            AsfDefinedTags.WmParentalRatingReason            },
			{ AsfDefinedTags.WmPartOfSet.Name,                       AsfDefinedTags.WmPartOfSet                       },
			{ AsfDefinedTags.WmPeakBitrate.Name,                     AsfDefinedTags.WmPeakBitrate                     },
			{ AsfDefinedTags.WmPeriod.Name,                          AsfDefinedTags.WmPeriod                          },
			{ AsfDefinedTags.WmPicture.Name,                         AsfDefinedTags.WmPicture                         },
			{ AsfDefinedTags.WmPlaylistDelay.Name,                   AsfDefinedTags.WmPlaylistDelay                   },
			{ AsfDefinedTags.WmProducer.Name,                        AsfDefinedTags.WmProducer                        },
			{ AsfDefinedTags.WmPromotionUrl.Name,                    AsfDefinedTags.WmPromotionUrl                    },
			{ AsfDefinedTags.WmProtectionType.Name,                  AsfDefinedTags.WmProtectionType                  },
			{ AsfDefinedTags.WmProvider.Name,                        AsfDefinedTags.WmProvider                        },
			{ AsfDefinedTags.WmProviderCopyright.Name,               AsfDefinedTags.WmProviderCopyright               },
			{ AsfDefinedTags.WmProviderRating.Name,                  AsfDefinedTags.WmProviderRating                  },
			{ AsfDefinedTags.WmProviderStyle.Name,                   AsfDefinedTags.WmProviderStyle                   },
			{ AsfDefinedTags.WmPublisher.Name,                       AsfDefinedTags.WmPublisher                       },
			{ AsfDefinedTags.WmRadioStationName.Name,                AsfDefinedTags.WmRadioStationName                },
			{ AsfDefinedTags.WmRadioStationOwner.Name,               AsfDefinedTags.WmRadioStationOwner               },
			{ AsfDefinedTags.WmSharedUserRating.Name,                AsfDefinedTags.WmSharedUserRating                },
			{ AsfDefinedTags.WmStreamTypeInfo.Name,                  AsfDefinedTags.WmStreamTypeInfo                  },
			{ AsfDefinedTags.WmSubscriptionContentId.Name,           AsfDefinedTags.WmSubscriptionContentId           },
			{ AsfDefinedTags.WmSubTitle.Name,                        AsfDefinedTags.WmSubTitle                        },
			{ AsfDefinedTags.WmSubTitleDescription.Name,             AsfDefinedTags.WmSubTitleDescription             },
			{ AsfDefinedTags.WmText.Name,                            AsfDefinedTags.WmText                            },
			{ AsfDefinedTags.WmToolName.Name,                        AsfDefinedTags.WmToolName                        },
			{ AsfDefinedTags.WmToolVersion.Name,                     AsfDefinedTags.WmToolVersion                     },
			{ AsfDefinedTags.WmTrack.Name,                           AsfDefinedTags.WmTrack                           },
			{ AsfDefinedTags.WmTrackNumber.Name,                     AsfDefinedTags.WmTrackNumber                     },
			{ AsfDefinedTags.WmUniqueFileIdentifier.Name,            AsfDefinedTags.WmUniqueFileIdentifier            },
			{ AsfDefinedTags.WmUserWebUrl.Name,                      AsfDefinedTags.WmUserWebUrl                      },
			{ AsfDefinedTags.WmVideoClosedCaptioning.Name,           AsfDefinedTags.WmVideoClosedCaptioning           },
			{ AsfDefinedTags.WmVideoFrameRate.Name,                  AsfDefinedTags.WmVideoFrameRate                  },
			{ AsfDefinedTags.WmVideoHeight.Name,                     AsfDefinedTags.WmVideoHeight                     },
			{ AsfDefinedTags.WmVideoWidth.Name,                      AsfDefinedTags.WmVideoWidth                      },
			{ AsfDefinedTags.WmWmaDRCAverageReference.Name,          AsfDefinedTags.WmWmaDRCAverageReference          },
			{ AsfDefinedTags.WmWmaDRCAverageTarget.Name,             AsfDefinedTags.WmWmaDRCAverageTarget             },
			{ AsfDefinedTags.WmWmaDRCPeakReference.Name,             AsfDefinedTags.WmWmaDRCPeakReference             },
			{ AsfDefinedTags.WmWmaDRCPeakTarget.Name,                AsfDefinedTags.WmWmaDRCPeakTarget                },
			{ AsfDefinedTags.WmWmCollectionGroupId.Name,             AsfDefinedTags.WmWmCollectionGroupId             },
			{ AsfDefinedTags.WmWmCollectionId.Name,                  AsfDefinedTags.WmWmCollectionId                  },
			{ AsfDefinedTags.WmWmContentId.Name,                     AsfDefinedTags.WmWmContentId                     },
			{ AsfDefinedTags.WmWmShadowFileSourceDrmType.Name,       AsfDefinedTags.WmWmShadowFileSourceDrmType       },
			{ AsfDefinedTags.WmWmShadowFileSourceFileType.Name,      AsfDefinedTags.WmWmShadowFileSourceFileType      },
			{ AsfDefinedTags.WmWriter.Name,                          AsfDefinedTags.WmWriter                          },
			{ AsfDefinedTags.WmYear.Name,                            AsfDefinedTags.WmYear                            }
		};
	}
}
