﻿using System;

namespace Owl.Asf
{
	/// <summary>
	/// タグの基本情報を表します。
	/// </summary>
	public class AsfTagInfo
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="name">名前。</param>
		/// <param name="type">データ型。</param>
		/// <param name="canEdit">編集可能な値ならば true。それ以外は false。</param>
		internal AsfTagInfo( string name, AsfTagDataType type, bool canEdit )
		{
			this.Name    = name;
			this.Type    = type;
			this.CanEdit = canEdit;
		}

		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="name">名前。</param>
		/// <param name="type">データ型。</param>
		internal AsfTagInfo( string name, AsfTagDataType type )
			: this( name, type, false )
		{
		}

		/// <summary>
		/// 指定された値の内容が適切な型を持っていることを調べます。
		/// </summary>
		/// <param name="type">AsfTagDataType の値。</param>
		/// <param name="value">値。</param>
		/// <returns>適切な型を持つ場合は true。それ以外は false。</returns>
		internal bool IsValidType( object value )
		{
			switch( this.Type )
			{
			case AsfTagDataType.Bool:   return ( value is bool   );
			case AsfTagDataType.Guid:   return ( value is Guid   );
			case AsfTagDataType.String: return ( value is string );
			case AsfTagDataType.UInt16: return ( value is ushort );
			case AsfTagDataType.UInt32: return ( value is uint   );
			case AsfTagDataType.UInt64: return ( value is ulong  );
			default:                    return ( value is byte[] );
			}
		}

		/// <summary>
		/// 編集可能であることを示す値を取得します。
		/// </summary>
		public bool CanEdit { get; private set; }

		/// <summary>
		/// 名前を取得します。
		/// </summary>
		public string Name { get; private set; }

		/// <summary>
		/// データ型を取得します。
		/// </summary>
		public AsfTagDataType Type { get; private set; }
	}
}
