﻿using System;
using System.Text;

namespace Owl
{
	/// <summary>
	/// 文字列に関するユーティリティ クラスです。
	/// </summary>
	static class StringUtility
	{
		/// <summary>
		/// 文字列の終端に存在する NULL 文字を削除します。
		/// </summary>
		/// <param name="str">文字列。</param>
		/// <returns>終端の NULL 文字を削除した文字列。</returns>
		public static string TrimLastNull( string str )
		{
			if( str.Length > 0 && str[ str.Length - 1 ] == '\0' )
			{
				// NULL 文字のみなら空文字として扱う
				if( str.Length == 1 ) { return String.Empty; }

				// 終端の NULL 文字をトリミング
				var sb = new StringBuilder( str );
				do
				{
					sb.Remove( sb.Length - 1, 1 );
				} while( sb.Length > 0 && sb[ sb.Length - 1 ] == '\0' );

				str = sb.ToString();
			}

			return str;
		}

		/// <summary>
		/// BOM 付きの UTF-16 文字列を表すバイト配列を、文字列に変換します。
		/// </summary>
		/// <param name="value">バイト配列。</param>
		/// <param name="index">バイト配列の変換を開始する位置。</param>
		/// <param name="count">変換をおこなうバイト数。</param>
		/// <returns>文字列。</returns>
		public static string GetStringUtf16WithBom( byte[] bytes, int index, int count )
		{
			// BOM 分 + 1 文字に満たないなら、空文字として扱う
			if( bytes == null || bytes.Length < 3 ) { return String.Empty; }

			// 適切な BOM が設定されていたら、後続バイトを文字列化する。
			if( bytes[ index ] == 0xFE && bytes[ index + 1 ] == 0xFF )
			{
				return Encoding.BigEndianUnicode.GetString( bytes, index + 2, count );
			}
			else if( bytes[ index ] == 0xFF && bytes[ index + 1 ] == 0xFE )
			{
				return Encoding.Unicode.GetString( bytes, index + 2, count );
			}
			else
			{
				return String.Empty;
			}
		}

		/// <summary>
		/// BOM 付きの UTF-16 文字列を表すバイト配列を、文字列に変換します。
		/// </summary>
		/// <param name="value">バイト配列。</param>
		/// <returns>文字列。</returns>
		public static string GetStringUtf16WithBom( byte[] bytes )
		{
			return StringUtility.GetStringUtf16WithBom( bytes, 0, bytes.Length );
		}
	}
}
