﻿using System;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using Owl.Id3;

namespace TestApp
{
	/// <summary>
	/// ID3 タグの編集テストをおこないます。
	/// </summary>
	static class TestId3
	{
		/// <summary>
		/// タグ情報をダンプします。
		/// </summary>
		/// <param name="args">コマンドライン引数。</param>
		/// <param name="textFileName">ダンプ先となるテキストファイルへのパス情報。</param>
		public static void Dump( string[] args, string textFileName )
		{
			string dumpFileName;
			{
				var dir = Path.GetDirectoryName( Assembly.GetEntryAssembly().Location );
				dumpFileName = String.Format( "{0}\\{1}", dir, textFileName );
			}

			// 前回、出力されてたテキストがあれば削除する
			if( File.Exists( dumpFileName ) && args.Length > 0 )
			{
				File.Delete( dumpFileName );
			}

			// 引数指定された ASF ファイルのタグ情報をまとめて出力
			for( int i = 0; i < args.Length; ++i )
			{
				TestId3.TryDumpV1( args[ i ], dumpFileName );
				TestId3.TryDumpV2( args[ i ], dumpFileName );
			}
		}

		/// <summary>
		/// タグ情報をダンプします。
		/// </summary>
		/// <param name="fileName">ファイルへのパス情報。</param>
		/// <param name="textFileName">ダンプ先となるテキストファイルへのパス情報。</param>
		public static void Dump( string fileName, string textFileName )
		{
			string dumpFileName;
			{
				var dir = Path.GetDirectoryName( Assembly.GetEntryAssembly().Location );
				dumpFileName = String.Format( "{0}\\{1}", dir, textFileName );
			}

			// 前回、出力されてたテキストがあれば削除する
			if( File.Exists( dumpFileName ) && File.Exists( fileName ) )
			{
				File.Delete( dumpFileName );
			}

			TestId3.TryDumpV1( fileName, dumpFileName );
			TestId3.TryDumpV2( fileName, dumpFileName );
		}

		/// <summary>
		/// ID3v1 のタグ情報をダンプします。
		/// </summary>
		/// <param name="filePath">ファイルのパス情報。</param>
		/// <param name="dumpFilePath">ダンプ先となるテキストファイルへのパス情報。</param>
		private static void TryDumpV1( string fileName, string dumpFileName )
		{
			try
			{
				Id3TagEditor.DumpV1( fileName, dumpFileName );
			}
			catch( Exception e )
			{
				Debug.WriteLine( e );
			}
		}

		/// <summary>
		/// ID3v2 のタグ情報をダンプします。
		/// </summary>
		/// <param name="filePath">ファイルのパス情報。</param>
		/// <param name="dumpFilePath">ダンプ先となるテキストファイルへのパス情報。</param>
		private static void TryDumpV2( string fileName, string dumpFileName )
		{
			try
			{
				Id3TagEditor.DumpV2( fileName, dumpFileName );
			}
			catch( Exception e )
			{
				Debug.WriteLine( e );
			}
		}
	}
}
